@@ -248,31 +248,6 @@ void NT_MoveToLineOrChar(int where,int line) {
 
 }
 void ScrollBuf(HANDLE hOut, CONSOLE_SCREEN_BUFFER_INFO *scrbuf,int where) {
-	
-	SMALL_RECT src;
-	COORD dest;
-	CHAR_INFO chr;
-
-
-	src.Left = scrbuf->srWindow.Left;
-	src.Top = scrbuf->srWindow.Top+where ;
-	src.Right = scrbuf->srWindow.Right;
-	src.Bottom = scrbuf->srWindow.Bottom;
-
-	dest.X = 0;
-	dest.Y = scrbuf->srWindow.Top;
-
-	chr.Char.AsciiChar = ' ';
-	chr.Attributes = scrbuf->wAttributes;
-
-	if (!ScrollConsoleScreenBuffer(hOut,
-									&src,
-									NULL,
-									dest,
-									&chr) ) {
-		;
-	}
-
 }
 void ConsolePageUpOrDown(BOOL Up) {
 
