@@ -55,7 +55,6 @@
 #pragma intrinsic("memcpy", "memset","memcmp")
 
 typedef unsigned long u_long;
-typedef unsigned long caddr_t;
 typedef void *ptr_t;
 typedef unsigned char U_char;	
 typedef unsigned int U_int;
@@ -115,6 +114,7 @@ NT_TIB * (* myNtCurrentTeb)(void);
 
 static NT_TIB *the_tib;
 
+#ifndef _M_IA64
 void *get_teb(void) {
 
 
@@ -131,6 +131,9 @@ void *get_teb(void) {
 		abort();
 	return the_tib;
 }
+#else
+#define get_teb NtCurrentTeb
+#endif _M_IA64
 
 /* 
  * This must be called by the application as the first thing it does.
@@ -149,9 +152,14 @@ int fork_init(void) {
 
 
 		// stack_probe probes out a decent-sized stack for the child,
-		// since initially it has a very small stack.
+		// since initially it has a very small stack (1 page).
 		//
-		stack_probe((char *)__fork_stack_end - 64);
+
+		/* not needed since default commit is set to 0.5MB in 
+		 * makefile.win32
+		 *
+		 * stack_probe((char *)__fork_stack_end - 64);
+		 */
 
 		//
 		// Save the old Exception registration record and jump
@@ -170,7 +178,8 @@ int fork_init(void) {
 }
 int fork(void) {
 
-	int rc,stacksize;
+	int rc;
+	size_t stacksize;
 	char modname[512];
 	HANDLE  hProc,hThread, hArray[2];
 	STARTUPINFO si;
@@ -182,17 +191,17 @@ int fork(void) {
 #ifndef _M_ALPHA
 	unsigned long fork_stack_end;
 #endif _M_ALPHA
-	unsigned long stackbase;
 
-	stackbase = (unsigned long)GETSTACKBASE();
-
-	__fork_stack_begin =(ULONG*)stackbase;
+	__fork_stack_begin =GETSTACKBASE();
 
 #ifndef _M_ALPHA
 	__fork_stack_end = &fork_stack_end;
 #else
 	__fork_stack_end = (unsigned long *)__asm("mov $sp, $0");
 #endif /*_M_ALPHA*/
+#ifdef _M_IA64
+	TlsFree(TlsAlloc());
+#endif _M_IA64
 	//
 	// Create two inheritable events
 	//
@@ -215,6 +224,7 @@ int fork(void) {
 #endif // _M_IX86
 		SetEvent(__hforkchild);
 
+		dprintf("Child ready to rumble\n");
 		if(WaitForSingleObject(__hforkparent,FORK_TIMEOUT) != WAIT_OBJECT_0)
 			ExitProcess(0xFFFF);
 
@@ -260,8 +270,10 @@ int fork(void) {
 						NULL,
 						&si,
 						&pi);
-	if (!rc) 
+	if (!rc)  {
+		rc = GetLastError();
 		return -1;
+	}
 	
 	ResetEvent(__hforkchild);
 	ResetEvent(__hforkparent);
@@ -294,6 +306,7 @@ int fork(void) {
 	if (WaitForMultipleObjects(2,hArray,FALSE,FORK_TIMEOUT) != WAIT_OBJECT_0){
 
 		int err = GetLastError(); // For debugging purposes
+		dprintf("wait failed err %d\n",err);
 		goto error;
 	}
 
@@ -306,18 +319,18 @@ int fork(void) {
 	}
 
 	// stack
-	stacksize = __fork_stack_begin - __fork_stack_end;
-	stacksize *= sizeof(unsigned long);
+	stacksize = (char*)__fork_stack_begin - (char*)__fork_stack_end;
 	if (!WriteProcessMemory(hProc,(char *)__fork_stack_end,
 								  (char *)__fork_stack_end,
-								  stacksize,
+								  (u_long)stacksize,
 								  &rc)){
 		goto error;
 	}
 	//
 	// copy heap itself
 	if (!WriteProcessMemory(hProc, (void*)__heap_base,(void*)__heap_base, 
-						__heap_top-__heap_base,&rc)){
+						(DWORD)((char*)__heap_top-(char*)__heap_base),
+						&rc)){
 		goto error;
 	}
 
@@ -374,9 +387,9 @@ void heap_init(void) {
 				abort();
 			}
 			else 
-				__heap_base = (u_long)temp;
+				__heap_base = temp;
 		}
-		if (!VirtualAlloc((void*)__heap_base,__heap_top - __heap_base, 
+		if (!VirtualAlloc(__heap_base,(char*)__heap_top -(char*)__heap_base, 
 								MEM_COMMIT,PAGE_READWRITE)){
 			err = GetLastError();
 			abort();
@@ -387,7 +400,7 @@ void heap_init(void) {
 		SYSTEM_INFO sysinfo;
 		GetSystemInfo(&sysinfo);
 		__heap_size = sysinfo.dwPageSize * 1024;
-		__heap_base = (unsigned long)VirtualAlloc(0 , __heap_size,MEM_RESERVE,
+		__heap_base = VirtualAlloc(0 , __heap_size,MEM_RESERVE,
 												PAGE_READWRITE);
 
 		if (__heap_base == 0) {
@@ -403,23 +416,24 @@ void heap_init(void) {
 //
 void * sbrk(int delta) {
 
-	 u_long retval,old_top=__heap_top;
+	 void *retval;
+	 void *old_top=__heap_top;
 
 	 if (delta == 0)
-	 	return (void*) __heap_top;
+	 	return  __heap_top;
 	 if (delta > 0) {
-	 	retval = (u_long)VirtualAlloc((void*)__heap_top, delta,MEM_COMMIT,
+	 	retval = VirtualAlloc((void*)__heap_top, delta,MEM_COMMIT,
 									PAGE_READWRITE);
 		if (retval == 0 )
 			abort();
-		__heap_top += delta;
+		(char*)__heap_top += delta;
 	 }
 	 else {
-	 	retval = (u_long)VirtualAlloc((void*)((char*)__heap_top-(char*)delta), 
+	 	retval = VirtualAlloc((void*)((char*)__heap_top-(char*)delta), 
 								delta,MEM_DECOMMIT, PAGE_READWRITE);
 		if (retval = 0)
 			abort();
-		__heap_top -= delta;
+		(char*)__heap_top -= delta;
 	}
 
 	return (void*) old_top;
