@@ -73,7 +73,11 @@ extern int OLDSTD, SHIN;
 int force_read(int fd, unsigned char * buf, int howmany) {
 	int numread=0,err=0;
 	HANDLE hRead ;
-	hRead= (HANDLE)_get_osfhandle(fd);
+
+	if (is_resource_file(fd))
+		return stringtable_read(fd,buf,howmany);
+
+	hRead= (HANDLE)__nt_get_osfhandle(fd);
 	if (hRead == INVALID_HANDLE_VALUE) {
 		return 0;
 	}
@@ -107,7 +111,10 @@ int nt_read(int fd, unsigned char * buf, int howmany) {
 	HANDLE hRead ;
 	DWORD ftype;
 	//
-	hRead= (HANDLE)_get_osfhandle(fd);
+	if (is_resource_file(fd))
+		return stringtable_read(fd,buf,howmany);
+
+	hRead= (HANDLE)__nt_get_osfhandle(fd);
 	if (hRead == INVALID_HANDLE_VALUE) {
 		return 0;
 	}
@@ -215,7 +222,7 @@ int nt_write(int fd, unsigned char * buf, int howmany)
 	HANDLE hout;
 
 
-	hout = (HANDLE)_get_osfhandle(fd);
+	hout = (HANDLE)__nt_get_osfhandle(fd);
 	/*
 	if (isatty(fd)) 
 ;//		return console_write(hout,buf,howmany);
@@ -245,6 +252,7 @@ int nt_write(int fd, unsigned char * buf, int howmany)
 
 #define IS_CTRL_COMBO(a) ( (a) & ( RIGHT_CTRL_PRESSED |  LEFT_CTRL_PRESSED) ) 
 #define IS_ALT_COMBO(a) ( /*(a) &*/ alt_pressed ) 
+#define IS_SHIFT_COMBO(a) ( (a) & SHIFT_PRESSED)
 
 int consoleread(HANDLE hInput, unsigned char * buf,int howmany) {
 
@@ -332,6 +340,8 @@ int consoleread(HANDLE hInput, unsigned char * buf,int howmany) {
 
 							else if (IS_ALT_COMBO(controlkey))
 								__nt_vcode += ALT_KEY_OFFSET;
+							else if (IS_SHIFT_COMBO(controlkey))
+								__nt_vcode += SHIFT_KEY_OFFSET;
 
 							__nt_want_vcode=2;
 
@@ -350,6 +360,8 @@ int consoleread(HANDLE hInput, unsigned char * buf,int howmany) {
 
 							else if (IS_ALT_COMBO(controlkey))
 								__nt_vcode += ALT_KEY_OFFSET;
+							else if (IS_SHIFT_COMBO(controlkey))
+								__nt_vcode += SHIFT_KEY_OFFSET;
 
 							__nt_want_vcode=2;
 							return 1;
@@ -364,6 +376,9 @@ int consoleread(HANDLE hInput, unsigned char * buf,int howmany) {
 							else if (IS_ALT_COMBO(controlkey))
 								__nt_vcode += ALT_KEY_OFFSET;
 
+							else if (IS_SHIFT_COMBO(controlkey))
+								__nt_vcode += SHIFT_KEY_OFFSET;
+
 							__nt_want_vcode=2;
 							return 1;
 						}
@@ -377,6 +392,9 @@ int consoleread(HANDLE hInput, unsigned char * buf,int howmany) {
 							else if (IS_ALT_COMBO(controlkey))
 								__nt_vcode += ALT_KEY_OFFSET;
 
+							else if (IS_SHIFT_COMBO(controlkey))
+								__nt_vcode += SHIFT_KEY_OFFSET;
+
 							__nt_want_vcode=2;
 
 							return 1;
@@ -456,3 +474,110 @@ int console_write(HANDLE hout, unsigned char * buf,int howmany) {
 		
 	return bytes;
 }
+int stringtable_read(int fd, char * buf, int howmany) {
+	int copied;
+	int rc;
+
+	static HMODULE hMod;
+	static int read_once = 0;
+	static long resline;
+	static long strpos;
+	static char oembuf[256];
+	WCHAR buffer[256];
+
+
+	if (read_once) {
+		return 0;
+	}
+
+	if (resline == 0) {
+		hMod = (HMODULE)__nt_get_osfhandle(fd);
+		resline = 666;
+	}
+
+	copied = 0;
+
+	if (strpos != 0) {
+
+
+		while(copied < howmany ) {
+
+			// end of line
+			if (oembuf[strpos] == 0) {
+
+				// if these fall at the end of the buffer, we should
+				// handle that.
+				*buf++ = '\r';
+				*buf++ = '\n';
+				copied +=2;
+
+				strpos = 0;
+
+				resline++; //next line
+
+				break;
+			}
+
+			*buf = oembuf[strpos];
+			buf++;
+			strpos++;
+			copied++;
+		}
+
+		if (howmany == copied) //else read more;
+			return copied;
+	}
+
+
+	while(howmany > copied) {
+
+		if (gdwPlatform == VER_PLATFORM_WIN32_WINDOWS) {
+			rc = LoadString(hMod,resline,oembuf,sizeof(oembuf));
+
+			if(!rc)
+				goto end_of_file;
+
+		}
+		else {
+			rc = LoadStringW(hMod,resline,buffer,sizeof(buffer));
+
+			if(!rc)
+				goto end_of_file;
+
+			WideCharToMultiByte(CP_OEMCP,
+					0,
+					buffer,
+					-1,
+					oembuf,
+					256,
+					NULL,NULL);
+		}
+		while(copied < howmany ) {
+
+			// end of line
+			if (oembuf[strpos] == 0) {
+
+				*buf++ = '\r';
+				*buf++ = '\n';
+				copied +=2;
+
+				strpos = 0;
+
+				resline++; //next line
+
+				break;
+			}
+
+			*buf = oembuf[strpos];
+			buf++;
+			strpos++;
+			copied++;
+		}
+
+	}
+	return copied;
+
+end_of_file:
+	read_once = 1;
+	return copied;
+}
