@@ -367,6 +367,41 @@ KEYCMD  CcEmacsMap[] = {
     F_UNASSIGNED,		/* DEL */
 
 /* alt key mappings */
+    F_UNASSIGNED,		/* f-1 */
+    F_UNASSIGNED,		/* f-2 */
+    F_UNASSIGNED,		/* f-3 */
+    F_UNASSIGNED,		/* f-4 */
+    F_UNASSIGNED,		/* f-5 */
+    F_UNASSIGNED,		/* f-6 */
+    F_UNASSIGNED,		/* f-7 */
+    F_UNASSIGNED,		/* f-8 */
+    F_UNASSIGNED,		/* f-9 */
+    F_UNASSIGNED,		/* f-10 */
+    F_UNASSIGNED,		/* f-11 */
+    F_UNASSIGNED,		/* f-12 */
+    F_UNASSIGNED,		/* f-13 */
+    F_UNASSIGNED,		/* f-14 */
+    F_UNASSIGNED,		/* f-15 */
+    F_UNASSIGNED,		/* f-16 */
+    F_UNASSIGNED,		/* f-17 */
+    F_UNASSIGNED,		/* f-18 */
+    F_UNASSIGNED,		/* f-19 */
+    F_UNASSIGNED,		/* f-20 */
+    F_UNASSIGNED,		/* f-21 */
+    F_UNASSIGNED,		/* f-22 */
+    F_UNASSIGNED,		/* f-23 */
+    F_UNASSIGNED,		/* f-24 */
+    F_UNASSIGNED,		/* PgUp */
+    F_UNASSIGNED,		/* PgDn */
+    F_UNASSIGNED,		/* end */
+    F_UNASSIGNED,		/* home */
+    F_UNASSIGNED,		/* LEFT */
+    F_UNASSIGNED,		/* UP */
+    F_UNASSIGNED,		/* RIGHT */
+    F_UNASSIGNED,		/* DOWN */
+    F_UNASSIGNED,		/* INS */
+    F_UNASSIGNED,		/* DEL */
+/* shift key mappings */
     F_UNASSIGNED,		/* f-1 */
     F_UNASSIGNED,		/* f-2 */
     F_UNASSIGNED,		/* f-3 */
@@ -773,6 +808,41 @@ KEYCMD  CcViMap[] = {
     F_UNASSIGNED,		/* DEL */
 
 /* alt key mappings */
+    F_UNASSIGNED,		/* f-1 */
+    F_UNASSIGNED,		/* f-2 */
+    F_UNASSIGNED,		/* f-3 */
+    F_UNASSIGNED,		/* f-4 */
+    F_UNASSIGNED,		/* f-5 */
+    F_UNASSIGNED,		/* f-6 */
+    F_UNASSIGNED,		/* f-7 */
+    F_UNASSIGNED,		/* f-8 */
+    F_UNASSIGNED,		/* f-9 */
+    F_UNASSIGNED,		/* f-10 */
+    F_UNASSIGNED,		/* f-11 */
+    F_UNASSIGNED,		/* f-12 */
+    F_UNASSIGNED,		/* f-13 */
+    F_UNASSIGNED,		/* f-14 */
+    F_UNASSIGNED,		/* f-15 */
+    F_UNASSIGNED,		/* f-16 */
+    F_UNASSIGNED,		/* f-17 */
+    F_UNASSIGNED,		/* f-18 */
+    F_UNASSIGNED,		/* f-19 */
+    F_UNASSIGNED,		/* f-20 */
+    F_UNASSIGNED,		/* f-21 */
+    F_UNASSIGNED,		/* f-22 */
+    F_UNASSIGNED,		/* f-23 */
+    F_UNASSIGNED,		/* f-24 */
+    F_UNASSIGNED,		/* PgUp */
+    F_UNASSIGNED,		/* PgDn */
+    F_UNASSIGNED,		/* end */
+    F_UNASSIGNED,		/* home */
+    F_UNASSIGNED,		/* LEFT */
+    F_UNASSIGNED,		/* UP */
+    F_UNASSIGNED,		/* RIGHT */
+    F_UNASSIGNED,		/* DOWN */
+    F_UNASSIGNED,		/* INS */
+    F_UNASSIGNED,		/* DEL */
+/* shift key mappings */
     F_UNASSIGNED,		/* f-1 */
     F_UNASSIGNED,		/* f-2 */
     F_UNASSIGNED,		/* f-3 */
@@ -1139,6 +1209,41 @@ KEYCMD  CcViCmdMap[] = {
     F_UNASSIGNED,		/* DEL */
 
 /* alt key mappings */
+    F_UNASSIGNED,		/* f-1 */
+    F_UNASSIGNED,		/* f-2 */
+    F_UNASSIGNED,		/* f-3 */
+    F_UNASSIGNED,		/* f-4 */
+    F_UNASSIGNED,		/* f-5 */
+    F_UNASSIGNED,		/* f-6 */
+    F_UNASSIGNED,		/* f-7 */
+    F_UNASSIGNED,		/* f-8 */
+    F_UNASSIGNED,		/* f-9 */
+    F_UNASSIGNED,		/* f-10 */
+    F_UNASSIGNED,		/* f-11 */
+    F_UNASSIGNED,		/* f-12 */
+    F_UNASSIGNED,		/* f-13 */
+    F_UNASSIGNED,		/* f-14 */
+    F_UNASSIGNED,		/* f-15 */
+    F_UNASSIGNED,		/* f-16 */
+    F_UNASSIGNED,		/* f-17 */
+    F_UNASSIGNED,		/* f-18 */
+    F_UNASSIGNED,		/* f-19 */
+    F_UNASSIGNED,		/* f-20 */
+    F_UNASSIGNED,		/* f-21 */
+    F_UNASSIGNED,		/* f-22 */
+    F_UNASSIGNED,		/* f-23 */
+    F_UNASSIGNED,		/* f-24 */
+    F_UNASSIGNED,		/* PgUp */
+    F_UNASSIGNED,		/* PgDn */
+    F_UNASSIGNED,		/* end */
+    F_UNASSIGNED,		/* home */
+    F_UNASSIGNED,		/* LEFT */
+    F_UNASSIGNED,		/* UP */
+    F_UNASSIGNED,		/* RIGHT */
+    F_UNASSIGNED,		/* DOWN */
+    F_UNASSIGNED,		/* INS */
+    F_UNASSIGNED,		/* DEL */
+/* shift key mappings */
     F_UNASSIGNED,		/* f-1 */
     F_UNASSIGNED,		/* f-2 */
     F_UNASSIGNED,		/* f-3 */
@@ -1184,7 +1289,7 @@ Char nt_translate_bindkey(Char*s) {
 	extern int lstricmp(char*,char*);
 	char *str = short2str(s);
 	short fkey;
-	char corm; /* 1 for ctrl map, 2 for meta map*/
+	char corm; /* 1 for ctrl map, 2 for meta map, 3 for shift map*/
 	Char keycode = 0;
 
 	corm = 0;
@@ -1193,9 +1298,11 @@ Char nt_translate_bindkey(Char*s) {
 		corm= 1;
 	else if (str[0] == 'M')
 		corm = 2;
+	else if (str[0] == 'S') /*shift keymap by avner.lottem@intel.com*/
+		corm = 3;
 
 	if (corm)
-		str += 2; /* skip C- or M-*/
+		str += 2; /* skip C- or M- or S-*/
 	
 	fkey = atoi(str);
 	if (fkey !=0) {
@@ -1240,6 +1347,8 @@ Char nt_translate_bindkey(Char*s) {
 			keycode +=  CTRL_KEY_OFFSET;
 		else if (corm == 2)
 			keycode +=  ALT_KEY_OFFSET;
+		else if (corm == 3)
+			keycode +=  SHIFT_KEY_OFFSET;
 	}
 
 	return keycode;
