@@ -35,7 +35,7 @@
  */
 #define _h_tc_const
 #include "sh.h"
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 Char STRigncase[]	= { 'i', 'g', 'n', 'c', 'a', 's', 'e', '\0' };
 Char STRoldtitle[]	= { 'o', 'l', 'd', 't', 'i', 't', 'l', 'e', '\0' };
 Char STRNTlamepathfix[] = { 'N', 'T', 'l', 'a', 'm', 'e', 'p', 'a', 't', 'h',
@@ -47,6 +47,8 @@ Char STRtcshonlystartexes[] = { 'T', 'C', 'S', 'H', 'O', 'N', 'L', 'Y', 'S',
 				'T', 'A', 'R', 'T', 'E', 'X', 'E', 'S', '\0' };
 Char STRNTslowexec[] = {'N','T','s','l','o','w','e','x','e','c','\0'};
 
+Char STRNTcaseifypwd[]={'N','T','c','a','s','e','i','f','y','p','w','d','\0'};
 Char STRdotEXE[] = {'.','E','X','E','\0'};
 
-#endif /* WINNT */
+Char STRNTnoquoteprotect[]={'N','T','n','o','q','u','o','t','e','p','r','o','t','e','c','t','\0'};
+#endif /* WINNT_NATIVE */
