@@ -65,9 +65,13 @@ struct	biltins nt_bfunc[] = {
 #ifdef NTDBG
     { "debugbreak",	dodebugbreak,	0,	0	},
 #endif /* NTDBG */
+    { "sourcerc",dosourceresource,0,1	},
+    { "printrc",doprintresource,0,1	},
     { "ps",	dops,	0,	1	},
     { "shutdown",	doshutdown,	0,	2	},
+#if 0
     { "stacksize",	dostacksize,0,	1	},
+#endif 0
     { "start",		dostart,	1,	INF	},
     { "title",		dotitle,	1,	INF	},
 };
@@ -273,7 +277,7 @@ void dostart(Char ** vc, struct command *c) {
 
 			errno = ENOEXEC;
 
-			if (!__nt_only_start_exes)
+			//if (!__nt_only_start_exes)
 				try_shell_ex(&v[k],0);
 
 			heap_free(cmdstr); /* free !! */
@@ -589,8 +593,10 @@ void init_shell_dll(void) {
 	if (!rc || (rc > 255))
 		return;
 
-	if (rc == 1)
+	if (rc == 1) {
 		__nt_only_start_exes = 1;
+		return;
+	}
 
 	ptr = &no_assoc[0];
 	i = 0;
@@ -1083,9 +1089,8 @@ executable(dir, name, dir_ok)
 	struct stat stbuf;
 	Char    path[MAXPATHLEN + 1];
 	char   *strname;
-	char extension[MAXPATHLEN];
-	char *ptr = short2str(path);
-	char *p2 = ptr;
+	char extension[MAXPATHLEN]; //bugfix by Avner Lottem.avner.lottem@intel.com
+	char *ptr, *p2 ;
 	int has_ext = 0;
 	extern void copyn(Char *, Char *, int);
 	extern void catn(Char *, Char *, int);
@@ -1096,6 +1101,8 @@ executable(dir, name, dir_ok)
 		copyn(path, dir, MAXPATHLEN);
 		catn(path, name, MAXPATHLEN);
 
+		p2 = ptr = short2str(path);
+
 		while (*ptr++)
 			continue;
 		--ptr;
@@ -1170,3 +1177,54 @@ nodot:
 	hashval = hashname(str2short(file));
 	bis_extern(hashval, i);
 }
+void dosourceresource(Char ** vc, struct command *c) {
+
+	extern srcfile(char*,int,int,char*);
+	USE(c);
+	USE(vc);
+
+	srcfile("/dev/builtinresource",0,0,NULL);
+}
+void doprintresource(Char ** vc, struct command *c) {
+
+	static char oembuf[256];
+	WCHAR buffer[256];
+	int rc;
+	HANDLE hMod = GetModuleHandle(NULL);
+	int i = 666;
+
+	USE(c);
+	USE(vc);
+
+	do {
+
+		if (gdwPlatform == VER_PLATFORM_WIN32_WINDOWS) {
+			rc = LoadString(hMod,i,oembuf,sizeof(oembuf));
+			if(!rc)
+				return;
+			oembuf[rc] = 0;
+
+		}
+		else {
+			rc = LoadStringW(hMod,i,buffer,sizeof(buffer));
+
+			if(!rc)
+				return;
+
+			rc = WideCharToMultiByte(CP_OEMCP,
+					0,
+					buffer,
+					-1,
+					oembuf,
+					256,
+					NULL,NULL);
+
+			if (rc)
+				oembuf[rc-1] = 0;
+		}
+
+		xprintf("%s\n",oembuf);
+
+		i++;
+	}while(rc);
+}
