@@ -160,18 +160,6 @@ char * forward_slash_get_cwd(char * path, int maxlen) {
 
 	path_slashify(ptemp);
 
-#if 0
-	while(*ptemp) {
-#ifdef DSPMBYTE
-		if (Ismbyte1(*ptemp) && *(ptemp + 1))
-			ptemp ++;
-		else
-#endif /* DSPMBYTE */
-		if (*ptemp == '\\') 
-			*ptemp = '/';
-		*ptemp++;
-	}
-#endif 0
 	return path;
 }
 void getmachine (void) {
@@ -528,19 +516,6 @@ void silly_entry(void *peb) {
 	rc = GetEnvironmentVariable("HOME",buf,MAX_PATH);
 	if (rc && (rc < MAX_PATH)){
 		path_slashify(buf);
-#if 0
-		char *s = &buf[0];
-		while(*s){
-#ifdef DSPMBYTE
-			if (Ismbyte1(*s) && *(s + 1)) 
-				s++;
-			else
-#endif /* DSPMBYTE */
-			if (*s == '\\')
-				*s = '/';
-			s++;
-		}
-#endif 0
 		(void)SetEnvironmentVariable("HOME",buf);
 		goto skippy;
 	}
@@ -576,18 +551,6 @@ void silly_entry(void *peb) {
 		MessageBox(NULL,"Unknown platform","tcsh",MB_ICONHAND);
 	}
 	path_slashify(temp);
-#if 0
-	ptr = &temp[0];
-	while(*ptr) {
-#ifdef DSPMBYTE
-		if (Ismbyte1(*ptr) && *(ptr + 1)) ptr ++;
-		else
-#endif /* DSPMBYTE */
-		if(*ptr == '\\') 
-			*ptr ='/';
-		ptr++;
-	}
-#endif 0
 	SetEnvironmentVariable("HOME",temp);
 
 skippy:
