@@ -4,9 +4,10 @@
 /* remember to change both instance of the version -amol */
 
 #ifdef NTDBG
-#define LOCALSTR ",nt-rev-5.52-debug"
+#define LOCALSTR ",nt-rev-6.01-debug"
 #else
-#define LOCALSTR ",nt-rev-5.52"
+#define LOCALSTR ",nt-rev-6.01" //changed ordonly test in nt_open
+								//patches
 #endif NTDBG
 
 #endif VERSION_H
